@@ -55,7 +55,6 @@ def test_request_stubs_internals():
     request.should.have.property('method').being.equal('POST')
 
 
-
 def test_request_parse_querystring():
     ("HTTPrettyRequest#parse_querystring should parse unicode data")
 
@@ -212,7 +211,7 @@ def test_fakesock_socket_getpeercert(dt):
             ((u'organizationalUnitName', u'Domain Control Validated'),),
             ((u'commonName', u'*.somewhere.com'),)),
         u'subjectAltName': (
-            (u'DNS', u'*somewhere.com'),
+            (u'DNS', u'*.somewhere.com'),
             (u'DNS', u'somewhere.com'),
             (u'DNS', u'*')
         )
@@ -234,7 +233,6 @@ def test_fakesock_socket_ssl():
     result.should.equal(sentinel)
 
 
-
 @patch('httpretty.core.old_socket')
 @patch('httpretty.core.POTENTIAL_HTTP_PORTS')
 def test_fakesock_socket_connect_fallback(POTENTIAL_HTTP_PORTS, old_socket):
@@ -263,6 +261,7 @@ def test_fakesock_socket_close(old_socket):
     # Given a fake socket instance that is synthetically open
     socket = fakesock.socket()
     socket._closed = False
+    socket._connected_truesock = True
 
     # When I close it
     socket.close()
@@ -322,7 +321,7 @@ def test_fakesock_socket_real_sendall(old_socket):
     real_socket.recv.called.should.be.false
 
     # And the buffer is empty
-    socket.fd.getvalue().should.equal(b'')
+    socket.fd.read().should.equal(b'')
 
     # And connect was never called
     real_socket.connect.called.should.be.false
@@ -356,7 +355,7 @@ def test_fakesock_socket_real_sendall_when_http(old_socket):
     ])
 
     # And the buffer should contain the data from the server
-    socket.fd.getvalue().should.equal(b"response from server")
+    socket.fd.read().should.equal(b"response from server")
 
     # And connect was called
     real_socket.connect.called.should.be.true
@@ -391,7 +390,7 @@ def test_fakesock_socket_real_sendall_continue_eagain_when_http(socket, old_sock
     ])
 
     # And the buffer should contain the data from the server
-    socket.fd.getvalue().should.equal(b"after error")
+    socket.fd.read().should.equal(b"after error")
 
     # And connect was called
     real_socket.connect.called.should.be.true
@@ -424,7 +423,7 @@ def test_fakesock_socket_real_sendall_socket_error_when_http(socket, old_socket)
     real_socket.recv.assert_called_once_with(socket._bufsize)
 
     # And the buffer should contain the data from the server
-    socket.fd.getvalue().should.equal(b"")
+    socket.fd.read().should.equal(b"")
 
     # And connect was called
     real_socket.connect.called.should.be.true
@@ -432,7 +431,7 @@ def test_fakesock_socket_real_sendall_socket_error_when_http(socket, old_socket)
 
 @patch('httpretty.core.old_socket')
 @patch('httpretty.core.POTENTIAL_HTTP_PORTS')
-def test_fakesock_socket_real_sendall_when_http(POTENTIAL_HTTP_PORTS, old_socket):
+def test_fakesock_socket_real_sendall_when_sending_data(POTENTIAL_HTTP_PORTS, old_socket):
     ("fakesock.socket#real_sendall should connect before sending data")
     # Background: the real socket will stop returning bytes after the
     # first call
@@ -464,7 +463,7 @@ def test_fakesock_socket_real_sendall_when_http(POTENTIAL_HTTP_PORTS, old_socket
     ])
 
     # And the buffer should contain the data from the server
-    socket.fd.getvalue().should.equal(b"response from foobar :)")
+    socket.fd.read().should.equal(b"response from foobar :)")
 
 
 @patch('httpretty.core.old_socket')
